Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1443)

Unified Diff: media/filters/ffmpeg_h265_to_annex_b_bitstream_converter.h

Issue 2534193003: To M56: Roll src/third_party/ffmpeg/ 3c7a09882..cdf4accee (3188 commits). (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/filters/ffmpeg_h265_to_annex_b_bitstream_converter.h
diff --git a/media/filters/ffmpeg_h265_to_annex_b_bitstream_converter.h b/media/filters/ffmpeg_h265_to_annex_b_bitstream_converter.h
index badc37238102af91bfe35810ca9f28bd52d220eb..9b52a08324f8ff0087b3d78034032a4e9fe36b45 100644
--- a/media/filters/ffmpeg_h265_to_annex_b_bitstream_converter.h
+++ b/media/filters/ffmpeg_h265_to_annex_b_bitstream_converter.h
@@ -13,7 +13,7 @@
#include "media/formats/mp4/hevc.h"
// Forward declarations for FFmpeg datatypes used.
-struct AVCodecContext;
+struct AVCodecParameters;
struct AVPacket;
namespace media {
@@ -23,11 +23,11 @@ namespace media {
class MEDIA_EXPORT FFmpegH265ToAnnexBBitstreamConverter
: public FFmpegBitstreamConverter {
public:
// The |stream_codec_context| will be used during conversion and should be the
// AVCodecContext for the stream sourcing these packets. A reference to
// |stream_codec_context| is retained, so it must outlive this class.
explicit FFmpegH265ToAnnexBBitstreamConverter(
- AVCodecContext* stream_codec_context);
+ AVCodecParameters* stream_codec_parameters);
~FFmpegH265ToAnnexBBitstreamConverter() override;
@@ -39,7 +39,7 @@ class MEDIA_EXPORT FFmpegH265ToAnnexBBitstreamConverter
// Variable to hold a pointer to memory where we can access the global
// data from the FFmpeg file format's global headers.
- AVCodecContext* stream_codec_context_;
+ AVCodecParameters* stream_codec_parameters_;
DISALLOW_COPY_AND_ASSIGN(FFmpegH265ToAnnexBBitstreamConverter);
};
@@ -23,11 +23,11 @@ namespace media {
: public FFmpegBitstreamConverter {
public:
- // The |stream_codec_context| will be used during conversion and should be the
- // AVCodecContext for the stream sourcing these packets. A reference to
- // |stream_codec_context| is retained, so it must outlive this class.
+ // The |stream_codec_parameters| will be used during conversion and should be
+ // the AVCodecParameters for the stream sourcing these packets. A reference to
+ // |stream_codec_parameters| is retained, so it must outlive this class.
explicit FFmpegH265ToAnnexBBitstreamConverter(

Powered by Google App Engine
This is Rietveld 408576698